# ServiceBus

> see https://aka.ms/autorest

This is the AutoRest configuration file for ServiceBus.



---
## Getting Started
To build the SDK for ServiceBus, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the ServiceBus API.

``` yaml
openapi-type: arm
tag: package-2017-04
```

### Tag: package-2018-01-preview

These settings apply only when `--tag=package-2018-01-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-01-preview'
input-file:
- Microsoft.ServiceBus/preview/2018-01-01-preview/servicebus-preview.json
```

### Tag: package-2017-04

These settings apply only when `--tag=package-2017-04` is specified on the command line.


``` yaml $(tag) == 'package-2017-04'
input-file:
- Microsoft.ServiceBus/stable/2017-04-01/servicebus.json
```

Important notes:
On the advice of @fearthecowboy, the  `EncodingCaptureDescription` enum previously contained two values [`Avro`,`AvroDeflate`] ; the service has been changed (on 2018-01-17) and will not ever return the `AvroDeflate` value,
 however, we have left the value in the enum (in servicebus.json) so that existing clients won't suffer a binary breaking change
The `AvroDeflate` value will likely be removed in a future API version, and at that a breaking binary change may happen.

### Tag: package-2015-08

These settings apply only when `--tag=package-2015-08` is specified on the command line.

``` yaml $(tag) == 'package-2015-08'
input-file:
- Microsoft.ServiceBus/stable/2015-08-01/servicebus.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_service_bus']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.ServiceBus
  output-folder: $(csharp-sdks-folder)/ServiceBus/Management.ServiceBus/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.servicebus
  package-name: azure-mgmt-servicebus
  package-version: 0.5.0
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-servicebus/azure/mgmt/servicebus
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-servicebus
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.servicebus
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-servicebus
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-08
  - tag: package-2017-04
```

### Tag: package-2015-08 and java

These settings apply only when `--tag=package-2015-08 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-08' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.servicebus.v2015_08_01
  output-folder: $(azure-libraries-for-java-folder)/servicebus/resource-manager/v2015_08_01
regenerate-manager: true
generate-interface: true
```

### Tag: package-2017-04 and java

These settings apply only when `--tag=package-2017-04 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-04' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.servicebus.v2017_04_01
  output-folder: $(azure-libraries-for-java-folder)/servicebus/resource-manager/v2017_04_01
regenerate-manager: true
generate-interface: true
```


